## About Vue Whoops Debug Component

A Vue 2 ajax debug component for Laravel 5.5+, pretty print Whoops style handler for ajax error responses in Laravel, auto handle error exceptions and user die dump responses from ajax requests in a pretty print style display.

Features live debug mode, iterate quickly through the debugging process of and ajax error untill the issue is resolved, automatic retries of your ajax request with the posted data, on an eventual success response the debug screen will auto close and your optional callback function will be called.

[![Video Demo](https://img.youtube.com/vi/n0U5a4S3crQ/0.jpg)](https://youtu.be/n0U5a4S3crQ "Video Demo")

## Installation

	npm install laravel-vue-whoops

### Apps Layout blade

Assuming that your project has retained the use of the original **layouts/app.blade.php** layout template, Add the following inside of the APP div tag as follows:

```php
<div id="app">
	<Whoops ref="Whoops"></Whoops>
</div>
```

### Import SCSS

```scss
@import "~laravel-vue-whoops/sass/whoops";
```


### Adding Whoops VUE Component

To register the Whoops component globally place the line below directly after where vue is imported ```import Vue from 'vue';```

```javascript
Vue.component('Whoops', require('laravel-vue-whoops'));
```

Example:

```javascript
import Vue from 'vue';

Vue.component('Whoops', require('laravel-vue-whoops'));

new Vue({
	el: '#app',
	components: {
		'myComponent': require('./components/myComponent.vue'),
	},
	data: function() {
		return {}
	}
});

```

## How to use

The **Whoops.handle** method takes two parameters.

#### Error
The error handle object parameter.

#### Callback
An optional error callback handler fallback.
If the error response is not an exception or dump then your callback should be your custom client facing UX handler, typically this would be your custom handler for laravel validation UX responses

```javascript
axios.patch(url,data).then(response => {

		// your success action here

	}).catch(error => {

	instance.$refs.Whoops.handle(error, function() {

		// your public facing fail action here
		alert('Hello Guest, Sorry but the server encountered an Internal Server Error during the processing your request!');

	});

});
```
